lists.arthurdejong.org
RSS feed

nss-pam-ldapd commit: r2075 - nss-pam-ldapd-0.8/common

[Date Prev][Date Next] [Thread Prev][Thread Next]

nss-pam-ldapd commit: r2075 - nss-pam-ldapd-0.8/common



Author: arthur
Date: Sat Mar 15 21:07:14 2014
New Revision: 2075
URL: http://arthurdejong.org/viewvc/nss-pam-ldapd?revision=2075&view=revision

Log:
also support poll() returning EAGAIN (2f088ec from 0.9)

Modified:
   nss-pam-ldapd-0.8/common/tio.c

Modified: nss-pam-ldapd-0.8/common/tio.c
==============================================================================
--- nss-pam-ldapd-0.8/common/tio.c      Sat Mar 15 20:36:37 2014        (r2074)
+++ nss-pam-ldapd-0.8/common/tio.c      Sat Mar 15 21:07:14 2014        (r2075)
@@ -189,10 +189,10 @@
       errno=ETIME;
       return -1;
     }
-    else if (errno!=EINTR)
+    else if ((errno!=EINTR)&&(errno!=EAGAIN))
       /* some error ocurred */
       return -1;
     /* we just try again on EINTR */
   }
 }
 
@@ -420,7 +420,7 @@
   rv=poll(fds,1,0);
   /* check if any file descriptors were ready (timeout) or we were
      interrupted */
-  if ((rv==0)||((rv<0)&&(errno==EINTR)))
+  if ((rv==0)||((rv<0)&&((errno==EINTR)||(errno==EAGAIN))))
     return 0;
   /* any other errors? */
   if (rv<0)
@@ -189,10 +189,10 @@
       /* some error ocurred */
       return -1;
-    /* we just try again on EINTR */
+    /* we just try again on EINTR or EAGAIN */
   }
 }
-- 
To unsubscribe send an email to
nss-pam-ldapd-commits-unsubscribe@lists.arthurdejong.org or see
http://lists.arthurdejong.org/nss-pam-ldapd-commits/